==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/mots/lang/mots_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Выделить группу:</b> данная группа будет визуально более заметной. Удобно использовать для обозначения важных групп ключей.',
	'avis_doublon_mot_cle' => 'Ключ с таким название уже существует. Вы уверенны, что хотите создать новый?', # MODIF

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Администраторы',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Автора',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Посетители для комментариев на сайте',

	// C
	'creer_et_associer_un_mot' => 'Создать и добавить ключ',

	// I
	'icone_creation_groupe_mots' => 'Новая группа ключей',
	'icone_creation_mots_cles' => 'Новый ключ',
	'icone_modif_groupe_mots' => 'Изменить группу ключей',
	'icone_modifier_mot' => 'Изменить ключ',
	'icone_mots_cles' => 'Ключи',
	'icone_supprimer_groupe_mots' => 'Удалить группу',
	'icone_voir_groupe_mots' => 'Просмотр группы',
	'icone_voir_tous_mots_cles' => 'Показать все ключи',
	'info_1_groupe_mots' => '1 группа ключей',
	'info_articles_lies_mot' => 'Статьи с ключом',
	'info_aucun_groupe_mots' => 'Нет групп ключей',
	'info_aucun_mot_cle' => 'Нет ключей',
	'info_changer_nom_groupe' => 'Название группы:',
	'info_creation_mots_cles' => 'Создание и настройка ключей',
	'info_dans_groupe' => 'В группе:',
	'info_delet_mots_cles' => 'Вы хотите удалить ключ <b>@titre_mot@</b> (@type_mot@).Он связан  с  <b>@texte_lie@</b>. Подтвердите удаление: ',
	'info_groupe_important' => 'Важная группа',
	'info_modifier_mot' => 'Изменить ключ:',
	'info_mots_cles' => 'Ключи',
	'info_mots_cles_association' => 'Ключи можно добавлять к:',
	'info_nb_groupe_mots' => '@nb@ групп ключей',
	'info_oui_suppression_mot_cle' => 'Я хочу удалить ключ.',
	'info_question_mots_cles' => 'Включить ключи на сайте?',
	'info_qui_attribue_mot_cle' => 'Ключи к материалам могут добавлять:',
	'info_remplacer_mot' => 'Заменить "@titre@"',
	'info_retirer_mot' => 'Убрать ключ',
	'info_retirer_mots' => 'Удалить все ключи',
	'info_rubriques_liees_mot' => 'Разделы с ключем',
	'info_selection_un_seul_mot_cle' => 'К материалу можно добавить только <b> один ключ </b> из этой группы.',
	'info_supprimer_mot' => 'удалить ключ',
	'info_titre_mot_cle' => 'Название ключа',
	'info_un_mot' => 'Только один ключ',
	'item_ajout_mots_cles' => 'Включить добавление ключей к комментариям на сайте',
	'item_non_ajout_mots_cles' => 'Отключить добавление ключей к комментариям на сайте',
	'item_non_utiliser_config_groupe_mots_cles' => 'Отключить настройку групп ключей',
	'item_non_utiliser_mots_cles' => 'Отключить ключи и группы ключей',
	'item_utiliser_config_groupe_mots_cles' => 'Включить настройку групп ключей',
	'item_utiliser_mots_cles' => 'Включить ключи и группы ключей',

	// L
	'lien_ajouter_mot' => 'Добавить ключ',
	'logo_groupe' => 'ЛОГОТИП ГРУППЫ',
	'logo_mot_cle' => 'ЛОГОТИП КЛЮЧА',

	// T
	'texte_config_groupe_mots_cles' => 'В настройках группы вы можете задавать к каким типам материалов можно добавлять ключи, выделять важные группы и ряд других настроек.',
	'texte_mots_cles' => 'Ключи - это возможность создать дополнительную навигацию между материалами сайта. Так же они используются для создания дополнительного функционала вашего сайта.',
	'texte_mots_cles_dans_forum' => 'Разрешить посетителям добавлять ключи к своим комментариям на сайте?',
	'texte_nouveau_mot' => 'Новый ключ',
	'titre_config_groupe_mots_cles' => 'Настройка групп ключей',
	'titre_gauche_mots_edit' => 'НОМЕР КЛЮЧА:',
	'titre_groupe_mots' => 'Группы ключей',
	'titre_groupe_mots_numero' => 'НОМЕР ГРУППЫ :',
	'titre_groupes_mots' => 'Группы ключей',
	'titre_mots_cles_dans_forum' => 'Ключи для комментариев',
	'titre_mots_tous' => 'Ключи',
	'titre_nouveau_groupe' => 'Новая группа',
	'titre_objets_lies_mot' => 'Материалы с этим ключем :',
	'titre_page_mots_tous' => 'Ключи'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mots/lang/mots_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Выделить группу:</b> данная группа будет визуально более заметной. Удобно использовать для обозначения важных групп ключей.',
	'avis_doublon_mot_cle' => 'Ключ с таким название уже существует. Вы уверены, что хотите создать новый?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Администраторы',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'Авторы',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'Посетители для комментариев на сайте',

	// C
	'creer_et_associer_un_mot' => 'Создать и добавить ключ',

	// I
	'icone_creation_groupe_mots' => 'Новая группа ключей',
	'icone_creation_mots_cles' => 'Новый ключ',
	'icone_modif_groupe_mots' => 'Изменить группу ключей',
	'icone_modifier_mot' => 'Изменить ключ',
	'icone_mots_cles' => 'Ключи',
	'icone_supprimer_groupe_mots' => 'Удалить группу',
	'icone_voir_groupe_mots' => 'Просмотр группы',
	'icone_voir_tous_mots_cles' => 'Показать все ключи',
	'info_1_groupe_mots' => '1 группа ключей',
	'info_articles_lies_mot' => 'Статьи с ключом',
	'info_aucun_groupe_mots' => 'Нет групп ключей',
	'info_aucun_mot_cle' => 'Нет ключей',
	'info_changer_nom_groupe' => 'Название группы:',
	'info_creation_mots_cles' => 'Создание и настройка ключей',
	'info_dans_groupe' => 'В группе:',
	'info_delet_mots_cles' => 'Вы хотите удалить ключ <b>@titre_mot@</b> (@type_mot@). Он связан с <b>@texte_lie@</b>. Подтвердите удаление: ',
	'info_groupe_important' => 'Важная группа',
	'info_modifier_mot' => 'Изменить ключ:',
	'info_mots_cles' => 'Ключи',
	'info_mots_cles_association' => 'Ключи этой группы можно добавлять к:',
	'info_nb_groupe_mots' => '@nb@ групп ключей',
	'info_oui_suppression_mot_cle' => 'Я хочу удалить ключ.',
	'info_question_mots_cles' => 'Включить ключи на сайте?',
	'info_qui_attribue_mot_cle' => 'Ключи к материалам могут добавлять:',
	'info_remplacer_mot' => 'Заменить «@titre@»',
	'info_retirer_mot' => 'Убрать ключ',
	'info_retirer_mots' => 'Удалить все ключи',
	'info_rubriques_liees_mot' => 'Разделы с ключом',
	'info_selection_un_seul_mot_cle' => 'К материалу можно добавить только  <b>один ключ</b> из этой группы.',
	'info_supprimer_mot' => 'удалить',
	'info_titre_mot_cle' => 'Название ключа',
	'info_un_mot' => 'Только один ключ',
	'item_ajout_mots_cles' => 'Включить добавление ключей к комментариям на сайте',
	'item_non_ajout_mots_cles' => 'Отключить добавление ключей к комментариям на сайте',
	'item_non_utiliser_config_groupe_mots_cles' => 'Отключить настройку групп ключей',
	'item_non_utiliser_mots_cles' => 'Отключить ключи и группы ключей',
	'item_utiliser_config_groupe_mots_cles' => 'Включить настройку групп ключей',
	'item_utiliser_mots_cles' => 'Включить ключи и группы ключей',

	// L
	'lien_ajouter_mot' => 'Добавить ключ',
	'logo_groupe' => 'ЛОГОТИП ГРУППЫ',
	'logo_mot_cle' => 'ЛОГОТИП КЛЮЧА',

	// T
	'texte_config_groupe_mots_cles' => 'В настройках группы вы можете задавать, к каким типам материалов можно добавлять ключи, выделять важные группы и ряд других настроек.',
	'texte_mots_cles' => 'Ключи - это возможность создать дополнительную навигацию между материалами сайта. Они также используются для создания дополнительного функционала вашего сайта.',
	'texte_mots_cles_dans_forum' => 'Разрешить посетителям добавлять ключи к своим комментариям на сайте?',
	'texte_nouveau_mot' => 'Новый ключ',
	'titre_config_groupe_mots_cles' => 'Настройка групп ключей',
	'titre_gauche_mots_edit' => 'НОМЕР КЛЮЧА:',
	'titre_groupe_mots' => 'Группа ключей',
	'titre_groupe_mots_numero' => 'НОМЕР ГРУППЫ:',
	'titre_groupes_mots' => 'Группы ключей',
	'titre_mots_cles_dans_forum' => 'Ключи для комментариев',
	'titre_mots_tous' => 'Ключи',
	'titre_nouveau_groupe' => 'Новая группа',
	'titre_objets_lies_mot' => 'Материалы с этим ключом:',
	'titre_page_mots_tous' => 'Ключи'
);

?>
